==> tabular-data-commons-2.2.0-20140702.033158-14-sources.jar: org/gcube/data/analysis/tabulardata/commons/templates/model/TemplateAction.java <==
package org.gcube.data.analysis.tabulardata.commons.templates.model;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.model.column.ColumnLocalId;
import org.gcube.data.analysis.tabulardata.model.column.ColumnReference;
import org.gcube.data.analysis.tabulardata.model.table.TableId;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public abstract class TemplateAction<T extends Serializable> implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public abstract T getIdentifier();	

	public abstract Map<String, Object> getParameters();

	public Map<String,Object> replaceColumnReferences(TableId tableId, Map<String, ColumnLocalId> columnMapping){
		Map<String,Object> parameters = getParameters();
		if (parameters==null || parameters.isEmpty())
			return parameters;
		Map<String, Object> returnMap = new HashMap<String, Object>();
		for (Entry<String, Object> entry: parameters.entrySet()){
			if (entry.getValue() instanceof ColumnReference){
				ColumnReference ref = (ColumnReference) entry.getValue();
				if (columnMapping.containsKey(ref.getColumnId().toString())){
					ColumnLocalId newId = columnMapping.get(ref.getColumnId().toString());
					ref.setColumnId(newId);
					ref.setTableId(tableId);
				}
			}
		}
		return returnMap;
	}
}

==> tabular-data-commons-2.4.2-20150211.032632-44-sources.jar: org/gcube/data/analysis/tabulardata/commons/templates/model/TemplateAction.java <==
package org.gcube.data.analysis.tabulardata.commons.templates.model;

import java.io.Serializable;
import java.util.HashMap;
import java.util.Map;
import java.util.Map.Entry;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlRootElement;

import org.gcube.data.analysis.tabulardata.model.column.ColumnLocalId;
import org.gcube.data.analysis.tabulardata.model.column.ColumnReference;
import org.gcube.data.analysis.tabulardata.model.table.TableId;

@XmlRootElement
@XmlAccessorType(XmlAccessType.FIELD)
public abstract class TemplateAction<T extends Serializable> implements Serializable{

	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public abstract boolean usesExpression();
	
	public abstract T getIdentifier();	

	public abstract Map<String, Object> getParameters();

	public Map<String,Object> replaceColumnReferences(TableId tableId, Map<String, ColumnLocalId> columnMapping){
		Map<String,Object> parameters = getParameters();
		if (parameters==null || parameters.isEmpty())
			return parameters;
		return getNewInstanceMap(tableId, columnMapping, getParameters());
	}
	
	@SuppressWarnings("unchecked")
	private Map<String,Object> getNewInstanceMap(TableId tableId, Map<String, ColumnLocalId> columnMapping, Map<String,Object> oldInstances){
		Map<String, Object> returnMap = new HashMap<String, Object>();
		for (Entry<String, Object> entry: oldInstances.entrySet()){
			if (entry.getValue() instanceof ColumnReference){
				ColumnReference ref = (ColumnReference) entry.getValue();
				if (columnMapping.containsKey(ref.getColumnId().toString())){
					ColumnLocalId newId = columnMapping.get(ref.getColumnId().toString());
					ref.setColumnId(newId);
				}
				returnMap.put(entry.getKey(), ref);
			}if (entry.getValue() instanceof String){
				if (columnMapping.containsKey(entry.getValue()))
					returnMap.put(entry.getKey(), columnMapping.get(entry.getValue()).getValue());								
			}if (entry.getValue() instanceof Map){ 
				Map<String, Object> compParam = (Map<String, Object>) entry.getValue();
				returnMap.put(entry.getKey(), getNewInstanceMap(tableId, columnMapping, compParam));
			} else returnMap.put(entry.getKey(), entry.getValue());
		}
		return returnMap;
	}
}
